==> colours_cli-0.5.0.tar.gz: colours_cli-0.5.0/colours_cli/comcol.py <==
"""
This is Command line tool for recognizing most Common colors in any given image
"""
#import argparse
from colours_library import colours

def recognizer():
    """
    Main function in this module
    """
    #initialize argpase obj
    #parser = argparse.ArgumentParser(description=
    #                                 'Takes 2 arguments path_to_file - string,\n' +
    #                                 'number_of_args - integer')
    #add arguments
    #parser.add_argument('Path',
    #                     metavar='path',
    #                     type=str,
    #                     help='Path to the image')
    #
    #parser.add_argument('Number_of_args',
    #                     metavar='numb_of_colors',
    #                     type=int,
    #                     help='Number of most common colors')
    #args = parser.parse_args()
    #input_path = args.Path
    #input_numb = args.Number_of_args
    while True:
        try:
            path = input('Add path to the image. ')
            numb = input('How many most frequent colors? ')
            mcc = colours.MostCommonColor(path, int(numb))
            output = mcc.produce()
            print(output)
            repeat = input('Do you want to repeat?\ny for yes \\ anything else for no ')
            if repeat == 'y':
                print('Let\'s go')
            else:
                break
        except FileNotFoundError:
            print('Seems like no such file exists ;/')
            print('try again')
        except TypeError:
            print('I work with jpg files only.')
            print('try again')
        except ValueError:
            print('No support for this color count.')
            print('try again')

==> colours_cli-0.7.0.tar.gz: colours_cli-0.7.0/colours_cli/comcol.py <==
"""
This is Command line tool for recognizing most Common colors in any given image
"""
#import argparse
from colours_library import colours
from webcolors import name_to_rgb

BREAKLINE = '----------------------------------'
def recognizer(if_rgb):
    """
    Main function in this module
    """
    to_rgb = if_rgb
    while True:
        try:
            #retrieving path and count input
            path = input('Add path to the image. \nIf u want to quit type q\n')
            if path == 'q':
                break
            numb = input('How many most frequent colors? ')
            print(BREAKLINE)
            #producing output
            mcc = colours.MostCommonColor(path, int(numb))
            output = mcc.produce()
            if to_rgb:
                print(name_to_rgb(output))
            print(output)
            #prompt if user wants to repeat
            repeat = input('Do you want to repeat?\ny for yes \\ anything else for no ')
            if repeat == 'y':
                print('Let\'s go')
                print(BREAKLINE)
            else:
                break
        except FileNotFoundError:
            print('Seems like no such file exists ;/')
            print('try again')
            print(BREAKLINE)
        except TypeError:
            print('I work with jpg files only.')
            print('try again')
            print(BREAKLINE)
        except ValueError:
            print('No support for this color count.')
            print('try again')
            print(BREAKLINE)
        finally:
            #path cleanup
            path = ""
